{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/tools_to_help_along_the_way_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/tools_to_help_along_the_way_650.jpg' %}"
             alt="Two students walk through the quad on the second day of Fall quarter.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=tools-help-you-along-way">Tools to Help You Along the Way</a></span></h4>
        <p><span class="myuw-highlight">Whether you’re just starting out or graduating soon, this collection of expert advice will help you maximize your learning and well-being. <a class="myuw-link-card-teaser" href="/husky_experience_message?article=tools-help-you-along-way">Read more</a></span></p>
    </div>
</div>
