{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/solve_world_problems_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/solve_world_problems_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/solve_world_problems_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %}"
             alt="Students and faculties on a boat in Puget Sound studying various fish.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></span></h4>
        <p><span class="myuw-highlight">You care deeply about something – climate change, human rights, clean energy, healthcare – and want to help solve world problems. Where to begin? <a class="myuw-link-card-teaser" href="/husky_experience_message?article=solve-world-problems">Read more</a></span></p>
    </div>
</div>
