{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Does Your Résumé Represent You?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/does_resume_represent_you_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/does_resume_represent_you_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/does_resume_represent_you_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/does_resume_represent_you_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/does_resume_represent_you_650.jpg' %}"
                     alt="Student working at a residence hall.">
            
            
                <p class="myuw-image-credit">Photo: Doug Plummer</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>The <a href="https://careers.uw.edu/resources/resumes-tips-advice/view/" target="_brand">Career Center</a> says the way to write about experiences for your résumé is to start with a verb, describe what you did, and end with a result. If you can, grab a buddy for this activity, so you can ask each other questions and unearth the knowledge and skills you used in a variety of tasks.</p> 

<h3>1. Brainstorm</h3>
<p>Get information on paper and don’t worry about perfection.</p>   
<p>Pick an experience (summer job, babysitting, volunteering, research, etc.). Write down the name of your employer or supervisor, your job title, dates of employment (the month and year you started and ended), and location.</p>
<p>Write one sentence that summarizes what you did – a short description of the whole experience. Just write, don’t edit.</p>
<p>Flesh out the description by considering questions like these, or have your buddy ask you these questions:</p>
<ul>
<li>What did you do on a typical day?</li>
<li>Were you involved in a project? From start to finish, or for what portion?</li> 
<li>Did you work alone or collaboratively? What was your role?</li> 
<li>Did you take on increasing duties and/or responsibilities over time?</li> 
<li>Did people receive better/faster service because of you?<li> 
<li>Did someone learn something from your instruction or participation?<li>
</ul>
<p>Again, just write.</p>

<p>Repeat the steps above for each experience (employment, volunteering) you plan to include on your résumé.</p> 

<h3>2. Translate</h3>
<p>Rewrite your brainstorm notes so that employers will understand exactly what you did.</p>

<p>Look at your first experience. Imagine an employer saying, "Tell me more." Experiment with ways to describe your experience more clearly and to be more specific and/or detailed. For example, if you initially wrote, “Constructed decks and patio covers” to describe your work, you might think about what other information an employer would want to know. Your new description might be, "Involved in planning through completion on the construction of custom decks and patio covers for residential clients.”</p> 

<p>Again, repeat this step for each experience you plan to include. When you're done, have your buddy or someone else read over all your descriptions and identify where they want more details. Revise as necessary.</p> 

<h3>3. Format &#38; Polish</h3> 
<p>Format and edit your résumé. Make it shine.</p>  
<p>Look at the Career Center <a href="https://careers.uw.edu/resources/resumes-tips-advice/view/" target="_blank"> guidelines </a> for formatting a résumé. Arrange your experiences in this format.</p>
<ul>
<li>Spell check.</li>
<li>Make sure your contact information is correct and your e-mail address is professional.</li>
<li>Adjust the font and headers so that there is a clear hierarchy of information. Make sure your résumé is easy to skim &#8211; the average review time is 10 seconds.</li>
<li>Hand your résumé to someone who is good at spelling, grammar and editing. Ask them to identify any errors and then correct these.</li> 
<li>Spell check again.</li>
</ul>
<p>Think about where you are submitting your résumé. Place the most relevant experience on top; it is critical for the reader to see a match between your experience and their job description in that 10-second skim.</p> 

<h3>Congratulate yourself</h3>
<p>Constructing a résumé is not easy, but you did it. It will get easier with practice.</p>
        </div>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=you-are-your-network">You Are Your Network</a></li>
                
                    <li><a href="/husky_experience_message?article=pitch-your-story">Pitch Your Story</a></li>
                
                    <li><a href="/husky_experience_message?article=got-experience">Got Experience?</a></li>
                
                    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
