{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">You Are Your Network</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/you_are_your_network_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/you_are_your_network_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/you_are_your_network_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/you_are_your_network_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/you_are_your_network_650.jpg' %}"
                     alt="Close-up of the building directory in Bagley Hall.">
            
            
        </figure>
        <div class="myuw-article-body">
        <h3>How to Weave Your Web</h3>
        <p>Imagine networking is like spinning a web: you are at the center and want to gather around you people with different strengths, personalities, connections and ways of relating to you. Job search gurus describe nine types of people to weave into your web:</p>

<ul>
<li><strong>Mentor</strong> – Someone you can learn from, someone who knows you well and who cares about your success</li>
<li><strong>Expert</strong> – Someone with expert information about the field you want to enter, and where it's headed </li>
<li><strong>Connector</strong> – Someone who's great at seeing opportunities and connecting you to people, resources and information</li>
<li><strong>Coach</strong> – Someone who helps you think through your decisions – and remains objective in the process</li>
<li><strong>Visionary</strong> – A “blue sky” thinker who fuels your dreams</li>
<li><strong>Realist</strong> – An “on the ground” pragmatist who gives you a reality check </li>
<li><strong>Guide</strong> – Someone who's been on the journey and who can help you make a plan for achieving your goal</li>
<li><strong>Fellow Traveler</strong> – Someone in a similar place as you, who can share your ups and downs</li>
<li><strong>Mentee</strong> – Someone one step behind you, who might appreciate your help</li>
</ul>

<p>This is a guide, not a formula, for thinking about your network and who you may want to add. Aim for diversity in your network – people from different fields, age groups, cultural backgrounds – as you think of people who could fill one or more roles. Eventually, you'll build a strong professional network that endures over time.</p>
        </div>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                
                    <li><a href="/husky_experience_message?article=your-friends-your-success">Your Friends, Your Success</a></li>
                
                    <li><a href="/husky_experience_message?article=first-impressions-matter">First Impressions Matter</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
