# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-26 17:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0005_article_image_alt_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='related_articles',
            field=models.ManyToManyField(blank=True, related_name='related_article', to='hx_toolkit.Article'),
        ),
    ]
