{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/bouncing_back_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/bouncing_back_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/bouncing_back_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %}"
             alt="Roses in bloom at the rose garden surrounding Drumheller Fountain.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=bouncing-back">Bouncing Back</a></span></h4>
        <p><span class="myuw-highlight">Everyone experiences failure. What can you learn when something goes wrong? <a class="myuw-link-card-teaser" href="/husky_experience_message?article=bouncing-back">Read more</a></span></p>
    </div>
</div>
