{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/you_are_your_network_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/you_are_your_network_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/you_are_your_network_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/you_are_your_network_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/you_are_your_network_650.jpg' %}"
             alt="Close-up of the building directory in Bagley Hall.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=you-are-your-network">You Are Your Network</a></span></h4>
        <p><span class="myuw-highlight">A web of differing professional contacts is the strongest net for catching a job. Who are they? <a class="myuw-link-card-teaser" href="/husky_experience_message?article=you-are-your-network">Read more</a></span></p>
    </div>
</div>
