{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">First Impressions Matter</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/first_impressions_matter_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/first_impressions_matter_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/first_impressions_matter_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %}"
                     alt="A student composing an email on his laptop in Paccar Hall.">
            
            
                <p class="myuw-image-credit">Photo: Dennis Wise</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>Your online presence should match who you are in real life. How you present yourself – and to whom – can make a difference. Email messages to faculty, mentors, and potential employers should be brief and professional.</p>
<p>Here are some tips that will help you make a good impression:</p>
<ul>
<li><strong>Include a useful subject line</strong> – a title like “meeting” will not be helpful for people who receive dozens of emails per day.</li>
<li><strong>Use a greeting at the beginning</strong> – You can’t go wrong with “Hello” or “Dear (their name).” Default to a formal title (e.g. Mr., Mrs., Dr.) unless you are already on a first-name basis.</li>
<li><strong>AVOID ALL CAPS!</strong> – Unless you really are intending to shout&#8230;.</li>
<li><strong>Double-check attachments</strong> – Are they attached? Are they titled appropriately?</li> 
<li><strong>Develop an email signature</strong> – Use something that includes more information about you, such as a link to your online profile or portfolio.</li>
</ul>
<p>Taking time to present yourself and communicate carefully will help you make good first impressions, both online and in-person.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://students.tufts.edu/career-center/i-need/network/professional-email-etiquette">Professional Email Etiquette</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                
                    <li><a href="/husky_experience_message?article=you-are-your-network">You Are Your Network</a></li>
                
                    <li><a href="/husky_experience_message?article=pitch-your-story">Pitch Your Story</a></li>
                
                    <li><a href="/husky_experience_message?article=first-impressions-matter">First Impressions Matter</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
