{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_650.jpg' %}"
             alt="Students with name tags sit at a round table smiling and laughing.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></span></h4>
        <p><span class="myuw-highlight">Most jobs emerge through people you know. Find out how to take the first step in building a professional network. <a class="myuw-link-card-teaser" href="/husky_experience_message?article=jobs-come-through-people-you-know">Read more</a></span></p>
    </div>
</div>
