{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Jobs Come Through People You Know</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/jobs_come_through_people_you_know_650.jpg' %}"
                     alt="Students with name tags sit at a round table smiling and laughing.">
            
            
                <p class="myuw-image-credit">Photo: UW College of Arts &amp; Sciences</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>Getting to know people in order to build your career is called networking. If this word and concept intimidate you, know you are in good company; most people cringe at the idea. There are, however, some easy ways to make connections with new people and strengthen connections you already have.</p> 

<h3>Your Current Communities</h3>
<p>The good news is that you already have a network in your friends and family. Add to that people that you know from different social organizations, such as RSOs, sports teams, or spiritual organizations. These connections are part of your network even though you don't know them in a professional setting. They may work at a job related to one you are seeking, and they might be able to share information and contacts that could help you in your job search. Don't be afraid to say to your connections, "I'm really interested in [name of field/job]. Is there someone you know who could help me learn more?"</p>

<h3>Making New Contacts</h3>
<p>You might be introduced to someone at an event, or you might have the opportunity to set up an informational interview with a new contact. A good way to break the ice is to ask the other person  purposeful questions. People generally like talking about themselves, including what they do for work and their interests. Place your focus on getting to know your new contact and thinking about how this person might fit into your network. You're not asking for a job, just more information. Try: </p>

<ul>
<li>What steps did you take that led to your current job? </li>
<li>What is the most satisfying aspect of your job? </li>
<li>What are the biggest challenges you face? </li>
<li>What would you differently if you had to do it all over again? </li>
<li>What one piece of advice do you have for someone starting out? </li>
</ul>

<h3>Stay Positive</h3>
<p>The way you present yourself makes a lasting impression. While it is normal to feel nervous or discouraged when talking to someone who might have a job connection, the key is to remain positive and optimistic when introducing yourself. Keep in mind that networking goes two ways – each person must benefit. Show an interest in the other person instead of focusing only on yourself and the outcome you want.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.gcflearnfree.org/jobsearchandnetworking/networking-basics/1/">Job Search and Networking Basics</a></li>
                
                    <li><a href="https://careers.uw.edu/resources/networking-activities/view/">Networking Activities Worksheet (PDF)</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=your-friends-your-success">Your Friends, Your Success</a></li>
                
                    <li><a href="/husky_experience_message?article=you-are-your-network">You Are Your Network</a></li>
                
                    <li><a href="/husky_experience_message?article=pitch-your-story">Pitch Your Story</a></li>
                
                    <li><a href="/husky_experience_message?article=first-impressions-matter">First Impressions Matter</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
