{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Falling in Love with a Class</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/falling_love_with_class_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/falling_love_with_class_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/falling_love_with_class_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/falling_love_with_class_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/falling_love_with_class_650.jpg' %}"
                     alt="UW students dancing at the Meany Hall dance studio.">
            
            
        </figure>
        <div class="myuw-article-body">
        <p>No matter your major (yes, some courses you just must take), choosing your classes continues to be a way to explore new ideas, challenge yourself, and be immersed in different worlds. You can make those NWs and VLPAs work for you!</p>


<h3>Finding a Match</h3>
<p>Here are some ideas for using opportunities wisely:</p>

<ul>
<li>Check out the current courses being taught by faculty who have won <a href=" http://www.washington.edu/teaching/awards/awards-recipients">Distinguished Teaching Awards</a>.</li>
<li>Think back on your favorite class or subject – what courses will give you the opportunity to dive deeper?</li>
<li>Is your favorite professor teaching something new? Email them and ask!</li>
<li>Advisers have <a href="https://www.washington.edu/uaa/advising/academic-planning/choosing-courses/courses-recommended-by-advisers">suggestions for great courses</a> in their departments; searching websites and blogs can often unearth some gems.</li>
<li>Ask your friends about their favorite classes.</li>
</ul>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.washington.edu/uaa/advising/academic-planning/choosing-courses/overview/">What Courses Should I Take?</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></li>
                
                    <li><a href="/husky_experience_message?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                
                    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                
                    <li><a href="/husky_experience_message?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
